@@ -949,7 +949,10 @@ bool View::showInfo(const vector<string> &text, int type)
 	SDL_RenderPresent(mrc);
 
 	grabInput(0);
-	ret = waitForKey(type);
+	if (type == WT_YESNO)
+		ret = waitForConfirmation();
+	else
+		ret = waitForKey(WT_ANYKEY);
 	grabInput(1);
 	return ret;
 }
@@ -1629,7 +1632,7 @@ void View::showFinalHiscores()
 	y = h/2;
 	renderHiscore(theme.fNormal, theme.fNormal, x,y,w,h,true);
 	SDL_RenderPresent(mrc);
-	waitForKey(false);
+	waitForKey(WT_ANYKEY);
 }
 
 int View::waitForKey(int type)
@@ -1776,9 +1779,9 @@ void View::showHelp()
 		"  - w to warp to next level (if enough bricks were destroyed)\n"
 		"  - p to pause/unpause the game\n"
 		"  - d to destroy a brick (workaround for bad level design)\n\n"
-		"If you leave a game you can resume it later (no hiscores entry yet).\n\n"
-		"If you loose all lives you can buy a continue (score set to 0, initial number of lives restored). "
-		"If you don't buy a continue the game is over (hiscores entry is checked) and can no longer be resumed. "
+		"If you leave a game, you can resume it later (no hiscores entry yet).\n\n"
+		"If you lose all lives, you can buy a continue (score set to 0, initial number of lives restored). "
+		"If you don't buy a continue, the game is over (hiscores entry is checked) and can no longer be resumed. "
 		"\n\nEnjoy the game!\n"
 		"          Michael Speck"
 		);
@@ -1848,7 +1851,7 @@ void View::showHelp()
 	SDL_RenderPresent(mrc);
 
 	waitForInputRelease();
-	waitForKey(false);
+	waitForKey(WT_ANYKEY);
 }
 
 void View::runBrickDestroyDlg()
